@@ -221,7 +221,7 @@ def insert_to_table_batchwise(
             cols = [*(batch[0])]
             targ_cols = ",".join(cols)
             bind_cols = ",:".join(cols)
-            insert_sql.format(targ_cols=targ_cols, bind_cols=bind_cols)
+            insert_sql = insert_sql.format(targ_cols=targ_cols, bind_cols=bind_cols)
         cur.executemany(insert_sql, batch)
         rows_inserted += cur.rowcount
     if enable_etl_logging:
